==> haskell-polyparse-1.11-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-polyparse/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.11
id: polyparse-1.11-83459d6d9df65afea2e279cf0b0fab90
key: polyp_5XYDSuF9x9Q8ty1hmIwch4
license: LGPL
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.Lex Text.Parse
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
    Text.ParserCombinators.Poly.Text
    Text.ParserCombinators.Poly.StateText
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/polyparse-1.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/polyparse-1.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/polyparse-1.11
hs-libraries: HSpolyparse-1.11-5XYDSuF9x9Q8ty1hmIwch4
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.11-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-polyparse/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.11
id: polyparse-1.11-32e1e4b83edd269be9945c81b189424b
key: polyp_GRsQpXwvEUxJXetVpxpw1R
license: LGPL
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.Lex Text.Parse
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
    Text.ParserCombinators.Poly.Text
    Text.ParserCombinators.Poly.StateText
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/polyparse-1.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/polyparse-1.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/polyparse-1.11
hs-libraries: HSpolyparse-1.11-GRsQpXwvEUxJXetVpxpw1R
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
